%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Microstructure Diffusion Toolbox
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

############
Introduction
############

.. include:: ../README.rst
   :start-line: 3


.. toctree::
    :maxdepth: 2
    :hidden:

    install
    getting_started
    concepts
    adding_models
    advanced_usage
    configuration
    FAQ <faq>
    changelog
    developers
    cli_index
    scientific_articles
